@@ -4,11 +4,8 @@ import java.util.List;
 
 import javax.ws.rs.GET;
 import javax.ws.rs.Path;
-import javax.ws.rs.Produces;
-import javax.ws.rs.core.MediaType;
 
 @Path("/tasks")
-@Produces(MediaType.APPLICATION_JSON)
 public class TaskResource {
 
     @GET
