@@ -3,8 +3,6 @@ package org.acme.security.keycloak.authorization;
 import javax.inject.Inject;
 import javax.ws.rs.GET;
 import javax.ws.rs.Path;
-import javax.ws.rs.Produces;
-import javax.ws.rs.core.MediaType;
 
 import io.quarkus.security.identity.SecurityIdentity;
 
@@ -16,7 +14,6 @@ public class UserResource {
 
     @GET
     @Path("/me")
-    @Produces(MediaType.APPLICATION_JSON)
     public User me() {
         return new User(keycloakSecurityContext);
     }
