@@ -1,8 +1,8 @@
 package org.acme.spring.data.jpa;
 
-import io.quarkus.test.junit.NativeImageTest;
+import io.quarkus.test.junit.QuarkusIntegrationTest;
 
-@NativeImageTest
+@QuarkusIntegrationTest
 class FruitResourceIT extends FruitResourceTest {
 
 }
