@@ -1,8 +1,8 @@
 package org.acme.spring.di;
 
-import io.quarkus.test.junit.NativeImageTest;
+import io.quarkus.test.junit.QuarkusIntegrationTest;
 
-@NativeImageTest
+@QuarkusIntegrationTest
 public class GreetingResourceIT extends GreetingResourceTest {
 
 }
