@@ -1,8 +1,8 @@
 package org.acme.validation;
 
-import io.quarkus.test.junit.NativeImageTest;
+import io.quarkus.test.junit.QuarkusIntegrationTest;
 
-@NativeImageTest
+@QuarkusIntegrationTest
 public class BookResourceIT extends BookResourceTest {
 
 }
\ No newline at end of file
